==> haskell-doctemplates-0.1.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.1.0.2
id: doctemplates-0.1.0.2-9WMrMrxOX1w1XUijiLVtvs
key: doctemplates-0.1.0.2-9WMrMrxOX1w1XUijiLVtvs
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    Please see README.md
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.DocTemplates
abi: 1310781634d95c4069d499160eba9008
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/doctemplates-0.1.0.2
hs-libraries: HSdoctemplates-0.1.0.2-9WMrMrxOX1w1XUijiLVtvs
depends:
    aeson-0.11.2.0-31ZI7bFuFz27ynqHifCKlM base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.1.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: doctemplates
version: 0.1.0.2
id: doctemplates-0.1.0.2-CGKVJbDBSyRLrxik9gkexg
key: doctemplates-0.1.0.2-CGKVJbDBSyRLrxik9gkexg
license: BSD3
copyright: 2016 John MacFarlane
maintainer: jgm@berkeley.edu
homepage: https://github.com/jgm/doctemplates#readme
synopsis: Pandoc-style document templates
description:
    Please see README.md
category: Text
author: John MacFarlane
exposed: True
exposed-modules:
    Text.DocTemplates
abi: 1b9f8dd3b76142d4843ac1aab5bb383a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/doctemplates-0.1.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/doctemplates-0.1.0.2
hs-libraries: HSdoctemplates-0.1.0.2-CGKVJbDBSyRLrxik9gkexg
depends:
    aeson-1.0.2.1-APwMyQyIboIL2RMSmpN5uA base-4.9.0.0
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP bytestring-0.10.8.1
    containers-0.5.7.1 parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    scientific-0.3.4.9-Ghl8M4Ey2fMI7e1yk2TuuH
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock
haddock-html: /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
